import { EmailLinkParams, FacebookLinkParams, FacebookMessengerLinkParams, GapLinkParams, HatenaLinkParams, InstaPaperLinkParams, LineLinkParams, LinkedInLinkParams, LiveJournalLinkParams, MailruLinkParams, PinterestLinkParams, PocketLinkParams, RedditLinkParams, TelegramLinkParams, TumblrLinkParams, TwitterLinkParams, VKShareLinkParams, ViberLinkParams, WeiboShareLinkParams, WhatsAppLinkParams, WorkplaceLinkParams } from '../types';
/**
 * Generates a Facebook sharing link.
 *
 * @param url - The URL to be shared.
 * @param quote - Optional. A quote or description to be included in the shared post.
 * @param hashtag - Optional. A hashtag to be included in the shared post.
 * @returns The Facebook sharing link.
 */
export declare function facebookLink(url: string, { quote, hashtag }: FacebookLinkParams): string;
/**
 * Generates a Email link for composing an email.
 *
 * @param url - The email address or addresses to send the email to.
 * @param subject - Optional. The subject line of the email.
 * @param body - Optional. The body content of the email.
 * @param separator - Optional. The separator to use between the body and the URL.
 * @returns The email link.
 */
export declare function emailLink(url: string, { subject, body, separator }: EmailLinkParams): string;
/**
 * Generates a Facebook Messenger link for sending a message.
 *
 * @param url - The URL to be shared within the message.
 * @param appId - Optional. The Facebook App ID or Your app's unique identifier..
 * @param redirectUri - Optional. The URL to redirect to after a person clicks a button on the dialog.
 * Required when using URL redirection.
 * @param to - Optional. A user ID of a recipient. Once the dialog comes up, the sender can
 * specify additional people as recipients.
 * @returns The Facebook Messenger link.
 */
export declare function facebookMessengerLink(url: string, { appId, redirectUri, to }: FacebookMessengerLinkParams): string;
export declare function gabLink(url: string, { title }: GapLinkParams): string;
export declare function hatenaLink(url: string, { title }: HatenaLinkParams): string;
export declare function instapaperLink(url: string, { title, description }: InstaPaperLinkParams): string;
export declare function lineLink(url: string, { title }: LineLinkParams): string;
export declare function linkedinLink(url: string, { title, summary, source }: LinkedInLinkParams): string;
export declare function liveJournalLink(_url: string, { title, description }: LiveJournalLinkParams): string;
export declare function mailruLink(url: string, { title, description, imageUrl }: MailruLinkParams): string;
export declare function pinterestLink(url: string, { media, description }: PinterestLinkParams): string;
export declare function pocketLink(url: string, { title }: PocketLinkParams): string;
export declare function redditLink(url: string, { title }: RedditLinkParams): string;
export declare function telegramLink(url: string, { title }: TelegramLinkParams): string;
export declare function tumblrLink(url: string, { title, caption, tags, posttype }: TumblrLinkParams): string;
export declare function twitterLink(url: string, { title, via, hashtags, related }: TwitterLinkParams): string;
export declare function viberLink(url: string, { title, separator }: ViberLinkParams): string;
export declare function vkLink(url: string, { title, image, noParse, noVkLinks }: VKShareLinkParams): string;
export declare function weiboLink(url: string, { title, image }: WeiboShareLinkParams): string;
export declare function whatsappLink(url: string, { title, separator }: WhatsAppLinkParams): string;
export declare function workplaceLink(url: string, { quote, hashtag }: WorkplaceLinkParams): string;
